## CELINE Unified Ontology Profile: Overview back to ToC

This ontology has the following classes and properties.

#### Classes

- Asset
- CO2 Emission Factor
- Energy Community
- Energy KPI
- Flexibility Event
- Forecast
- Meter
- Observation
- Prosumer
- Tariff
- Time Series

#### Object Properties

- evaluated by
- has CO2 factor
- has flexibility event
- has forecast
- has member
- has meter
- has observation
- has tariff
- has time series
- is located in
- measured consumption
- measured production
- owns asset

#### Data Properties

- point time
- point value
- timestamp
- value